==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/meta/v1alpha1/IstioStatusBuilder.java <==
package io.fabric8.istio.api.meta.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IstioStatusBuilder extends IstioStatusFluentImpl<IstioStatusBuilder> implements VisitableBuilder<IstioStatus,IstioStatusBuilder>{
  public IstioStatusBuilder() {
    this(false);
  }
  public IstioStatusBuilder(Boolean validationEnabled) {
    this(new IstioStatus(), validationEnabled);
  }
  public IstioStatusBuilder(IstioStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public IstioStatusBuilder(IstioStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IstioStatus(), validationEnabled);
  }
  public IstioStatusBuilder(IstioStatusFluent<?> fluent,IstioStatus instance) {
    this(fluent, instance, false);
  }
  public IstioStatusBuilder(IstioStatusFluent<?> fluent,IstioStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withConditions(instance.getConditions());
      fluent.withObservedGeneration(instance.getObservedGeneration());
      fluent.withValidationMessages(instance.getValidationMessages());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IstioStatusBuilder(IstioStatus instance) {
    this(instance,false);
  }
  public IstioStatusBuilder(IstioStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withValidationMessages(instance.getValidationMessages());
    }
    this.validationEnabled = validationEnabled; 
  }
  IstioStatusFluent<?> fluent;
  Boolean validationEnabled;
  public IstioStatus build() {
    IstioStatus buildable = new IstioStatus(fluent.getConditions(),fluent.getObservedGeneration(),fluent.getValidationMessages());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/meta/v1alpha1/IstioStatusBuilder.java <==
package io.fabric8.istio.api.meta.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IstioStatusBuilder extends IstioStatusFluent<IstioStatusBuilder> implements VisitableBuilder<IstioStatus,IstioStatusBuilder>{
  public IstioStatusBuilder() {
    this(false);
  }
  public IstioStatusBuilder(Boolean validationEnabled) {
    this(new IstioStatus(), validationEnabled);
  }
  public IstioStatusBuilder(IstioStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public IstioStatusBuilder(IstioStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IstioStatus(), validationEnabled);
  }
  public IstioStatusBuilder(IstioStatusFluent<?> fluent,IstioStatus instance) {
    this(fluent, instance, false);
  }
  public IstioStatusBuilder(IstioStatusFluent<?> fluent,IstioStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new IstioStatus());

    if (instance != null) {
      fluent.withConditions(instance.getConditions());
      fluent.withObservedGeneration(instance.getObservedGeneration());
      fluent.withValidationMessages(instance.getValidationMessages());
      fluent.withConditions(instance.getConditions());
      fluent.withObservedGeneration(instance.getObservedGeneration());
      fluent.withValidationMessages(instance.getValidationMessages());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IstioStatusBuilder(IstioStatus instance) {
    this(instance,false);
  }
  public IstioStatusBuilder(IstioStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new IstioStatus());

    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withValidationMessages(instance.getValidationMessages());
      this.withConditions(instance.getConditions());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withValidationMessages(instance.getValidationMessages());
    }
    this.validationEnabled = validationEnabled; 
  }
  IstioStatusFluent<?> fluent;
  Boolean validationEnabled;
  public IstioStatus build() {
    IstioStatus buildable = new IstioStatus(fluent.buildConditions(),fluent.getObservedGeneration(),fluent.buildValidationMessages());
    return buildable;
  }
  
}
